@@ -13,10 +13,12 @@
 #ifndef __NPACKAGESEARCH_GLOBALS_H_2005_09_30
 #define __NPACKAGESEARCH_GLOBALS_H_2005_09_30
 
+#include <QString>
+
 namespace NPackageSearch
 {
 
-const QString VERSION("2.6");
+const QString VERSION("2.7.3");
 
 }
 #endif	// __NPACKAGESEARCH_GLOBALS_H_2005_09_30
