@@ -23,10 +23,12 @@
 #include <qclipboard.h>
 #include <QCloseEvent>
 #include <qcursor.h>
+#include <QDesktopServices>
 #include <QDir>
 #include <qicon.h>
 #include <QList>
 #include <qmessagebox.h>
+#include <QNetworkAccessManager>
 #include <qpixmap.h>
 #include <qstatusbar.h>
 #include <QStringList>
@@ -37,14 +39,6 @@
 #include <QWhatsThis>
 #include <QtDebug>
 
-#include <xapian.h>
-
-#include <wibble/operators.h>
-
-#include <ept/apt/apt.h>
-#include <ept/debtags/debtags.h>
-#include <ept/debtags/vocabulary.h>
-#include <ept/axi/axi.h>
 
 
 // NApplication
@@ -83,6 +77,16 @@
 // NUtil
 #include "helpers.h"
 
+#undef slots
+#include <xapian.h>
+
+#include <wibble/operators.h>
+
+#include <ept/apt/apt.h>
+#include <ept/debtags/debtags.h>
+#include <ept/debtags/vocabulary.h>
+#include <ept/axi/axi.h>
+
 
 using namespace std;
 
@@ -98,7 +102,8 @@ template class LesserPriority<NPlugin::ShortInformationPlugin>;
 
 
 PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFlags fl )
-: QMainWindow(parent, fl), _DETAILS_INFORMATION_PRIORITY(2)
+: QMainWindow(parent, fl), _DETAILS_INFORMATION_PRIORITY(2), _network(NUtil::NetworkSettings::SYSTEM_PROXY)
+//_network(NUtil::NetworkSettings::ProxyType::SYSTEM_PROXY), no C++11 :(
 {
 	setObjectName(name);
 	setupUi(this);
@@ -161,7 +166,7 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WFl
     
 	connect(_pPackageView, SIGNAL(packageSelected(QString)), SLOT(onPackageSelectionChanged(QString)));
 	connect(_pPackageSelection, SIGNAL(activated(const QString&)), SLOT(selectNewPackage(QString)));
-	connect(_pDetailsView, SIGNAL(sourceChanged(const QUrl&)), SLOT(onLinkClicked(const QUrl&)));
+	connect(_pDetailsView, SIGNAL(anchorClicked(const QUrl&)), SLOT(onLinkClicked(const QUrl&)));
 	connect(_pInformationContainer, SIGNAL(currentChanged(int)), SLOT(onInformationPageChanged()));
 	// query aptDB for updates every 2s
 	connect(&timer, SIGNAL(timeout()), SLOT(checkAptDbForUpdates()));
@@ -272,7 +277,6 @@ void PackageSearchImpl::initialize()
 	}
 	while (!success);
 
-
 	// create the hard coded plugins
 	_pPackageNamePlugin = new NPlugin::PackageNamePlugin();
 	this->addPlugin(_pPackageNamePlugin);
@@ -297,6 +301,7 @@ void PackageSearchImpl::initialize()
 	setPackageActionsEnabled(false);
 }
 
+
 /////////////////////////////////////////////////////
 // IXmlStorable Interface
 /////////////////////////////////////////////////////
@@ -305,9 +310,10 @@ void PackageSearchImpl::saveSettings()
 {
 	NXml::XmlData xmlData("packagesearch");
 	QDomElement root = xmlData.root();
-	xmlData.addAttribute(root, QString("2"), "settingsVersion");
+	xmlData.addAttribute(root, QString("3"), "settingsVersion");
 	// changes:
 	// settings version 2: added "system" node
+	// settings version 3: added "network" node
 	
 	xmlData.addAttribute(root, _pMainToolBar->toggleViewAction()->isChecked(), "showMainToolbar");
 	
@@ -332,6 +338,9 @@ void PackageSearchImpl::saveSettings()
 	
 	QDomElement system = xmlData.addElement(xmlData.root(), "system");
 	xmlData.addAttribute(system, NApplication::RunCommand::gainRootCommand(), "gainRootCommand");
+
+	_network.saveSettings(xmlData, root);
+
 	_pPluginManager->saveSettings(xmlData, root);
 	if ( !xmlData.writeFile(_settingsFilename) )
 		reportError(tr("Unable to write settings"), tr("Unable to write settings to") +
@@ -418,6 +427,7 @@ void PackageSearchImpl::loadSettings()
 		NApplication::RunCommand::setGainRootCommand((NApplication::GainRoot) gainRootCommand);
 		element = NXml::getNextElement(element);
 	}
+	element = _network.loadSettings(element);
 	_pPluginManager->loadSettings(element);
 }
 
@@ -493,6 +503,11 @@ void PackageSearchImpl::reloadAptFrontCache()
 	_pApt = new ept::apt::Apt;
 }
 
+QNetworkAccessManager* PackageSearchImpl::network() 
+{
+	return _network.network();
+}
+
 /////////////////////////////////////////////////////
 // IPluginUser Interface
 /////////////////////////////////////////////////////
@@ -885,7 +900,7 @@ void PackageSearchImpl::onControlPlugins()
 
 void PackageSearchImpl::onPreferences()
 {
-	NPackageSearch::SettingsDlg dlg(this);
+	NPackageSearch::SettingsDlg dlg(_network, this);
 	// TODO grey out SUDO button if sudo is not available
 	switch (NApplication::RunCommand::gainRootCommand())
 	{
@@ -908,7 +923,7 @@ void PackageSearchImpl::onPreferences()
 			NApplication::RunCommand::setGainRootCommand(NApplication::SU);
 		else if (dlg._pSudoButton->isChecked())
 			NApplication::RunCommand::setGainRootCommand(NApplication::SUDO);
-			
+		_network = dlg.networkSettings();		
 		for_each( plugins.begin(), plugins.end(),
 				mem_fun(&NPlugin::PluginContainer::applySettings) );
 	}
@@ -924,7 +939,14 @@ void PackageSearchImpl::closeEvent(QCloseEvent* pE)
 
 void PackageSearchImpl::onLinkClicked( const QUrl& link)
 {
-	selectNewPackage(link.toString());
+	if ( link.scheme() == QString("package") ) 
+	{
+		selectNewPackage(link.path());
+	} 
+	else
+	{
+		QDesktopServices::openUrl(link);
+	}
 }
 
 void PackageSearchImpl::onForward()
