@@ -24,7 +24,7 @@ QDomElement Plugin::loadSettings(const QDomElement source)
 	return source;
 }
 
-void Plugin::saveSettings(NXml::XmlData& outData, QDomElement parent) const
+void Plugin::saveSettings(NXml::XmlData&, QDomElement) const
 {
 }
 
