@@ -63,16 +63,6 @@ public:
 	  * @param pLoader the observer where to report the reload progress, 0 if no progress should be reported  
 	  */
 	virtual void reloadPackageInformation(NUtil::IProgressObserver* pObserver) = 0;
-	/** @brief Returns the number of occurences of the handed pattern in the package description.
-	  *
-	  * @throws PackageNotFoundException if no package with this handle was in the database
-	  */
-	virtual int getDescriptionCount(const string& package, const QString& pattern, bool caseSensitive=false) const = 0;
-	/** @brief Returns if the name matches the the handed pattern.
-	  *
-	  * @throws PackageNotFoundException if no package with this handle was in the database
-	  */
-	virtual bool matchesName(const string& package, const QString& pattern, bool caseSensitive=false) const = 0;
 };
 
 } // NApt
