@@ -13,6 +13,9 @@
 #define __PLUGINSETTINGSDLG_H_2004_08_31
 
 #include <QDialog>
+#include <QNetworkProxy>
+
+#include <networksettings.h>
 
 #include "ui_settingsdlg.h"
 
@@ -35,10 +38,22 @@ class SettingsDlg : public QDialog, public Ui::SettingsDlg
 {
 Q_OBJECT
 public:
-	SettingsDlg(QWidget *parent = 0, const char *name = 0);
+	/** Initialises the dialog. 
+	 *
+	 * Initially the settings from the proxy are applied.
+	 */
+	SettingsDlg(const NUtil::NetworkSettings& network, QWidget *parent = 0, const char *name = 0);
 	~SettingsDlg();
-	/** Adds a plugin to show settings for. */
+	/** @brief Adds a plugin to show settings for. */
 	void addPlugin(NPlugin::PluginContainer* pPluginContainer);
+	/** @brief Applies the proxy settings configured within this GUI to the QNetworkProxy configuration. 
+	 *
+	 * Returns the proxy configured through this dialog.
+	 */
+	NUtil::NetworkSettings networkSettings();
+public Q_SLOTS:
+	void on__pProxyServerEnabledCheck_stateChanged(int state);
+	
 };
 
 };
